@@ -2,19 +2,39 @@
 
 
 
-use ::std::env;
-use ::std::fmt::{Write as _};
-use ::std::fs;
-use ::std::io;
-use ::std::io::{Write as _};
-use ::std::iter::Iterator;
-use ::std::path::{Path, PathBuf};
-use ::std::collections::BTreeSet;
+#[ allow (unused_imports) ]
+use ::std::{
+		
+		cell,
+		env,
+		ffi,
+		fmt,
+		fs,
+		io,
+		iter,
+		mem,
+		path,
+		rc,
+		
+		collections::BTreeSet,
+		iter::Iterator,
+		path::{Path, PathBuf},
+		
+		fmt::{Write as _},
+		io::{Write as _},
+		
+	};
+
 
-use ::sass_rs as sass;
 use ::walkdir;
 use ::blake2;
 
+#[ cfg (feature = "sass-rs") ]
+use ::sass_rs as sass;
+
+#[ cfg (feature = "sass-alt") ]
+use ::sass_alt as sass;
+
 
 
 
@@ -244,6 +264,7 @@ impl Builder {
 	}
 	
 	
+	#[ cfg (any (feature = "sass-rs", feature = "sass-alt")) ]
 	pub fn route_sass (&mut self, _source : &str, _route_builder : &(impl RoutePathBuilder + ?Sized)) -> () {
 		
 		let _css_sources = self.configuration.css_sources.as_ref () .expect ("[0d19f056]") .to_owned ();
@@ -459,6 +480,26 @@ impl Builder {
 	
 	
 	
+	pub fn watch_asset (&mut self, _source : &str) {
+		
+		let _assets_sources = self.configuration.assets_sources.as_ref () .expect ("[443c8ae5]");
+		let (_relative, _source) = self.resolve_file (_assets_sources, _source) .expect ("[256c60bf]");
+		
+		self.dependencies_include (&_source);
+	}
+	
+	pub fn watch_assets (&mut self, _sources : &str) -> () {
+		
+		let _assets_sources = self.configuration.assets_sources.as_ref () .expect ("[d807eb26]");
+		let (_paths, _folders) = self.resolve_files (_assets_sources, _sources) .expect ("[5ffa5360]");
+		self.dependencies_include_all (_folders.iter () .map (PathBuf::as_path));
+		
+		self.dependencies_include_all (_paths.iter () .map (|_pair| _pair.1.as_path ()));
+	}
+	
+	
+	
+	
 	pub fn generate (mut self) -> () {
 		
 		self.dependencies_extend ();
@@ -577,6 +618,7 @@ impl Builder {
 		}
 	}
 	
+	#[ allow (dead_code) ]
 	fn dependencies_exclude (&mut self, _path : &Path) -> () {
 		self.dependencies.remove (_path.into ());
 	}
@@ -616,12 +658,23 @@ impl Builder {
 impl Builder {
 	
 	
-	fn compile_sass (&self, _source : &Path, _search : &Path) -> Result<String, io::Error> {
+	#[ cfg (feature = "sass-rs") ]
+	fn compile_sass (&mut self, _source : &Path, _search : &Path) -> Result<String, io::Error> {
+		
+		let _extension = _source.extension () .expect ("[836ff108]") .to_str () .expect ("[4068e13f]");
+		let _indented_syntax = match _extension {
+			"sass" =>
+				true,
+			"scss" =>
+				false,
+			_ =>
+				panic! ("[720c0c23]"),
+		};
 		
 		let _options = sass::Options {
 				output_style : sass::OutputStyle::Expanded,
 				precision : 4,
-				indented_syntax : true,
+				indented_syntax : _indented_syntax,
 				include_paths : vec! [],
 			};
 		
@@ -631,6 +684,84 @@ impl Builder {
 		
 		return Ok (_data);
 	}
+	
+	
+	#[ cfg (feature = "sass-alt") ]
+	fn compile_sass (&mut self, _source : &Path, _search : &Path) -> Result<String, io::Error> {
+		
+		let _parent = _source.parent () .expect ("[f6ce0d79]");
+		
+		let _extension = _source.extension () .expect ("[f2cd37bc]") .to_str () .expect ("[db216e38]");
+		let _input_syntax = match _extension {
+			"sass" =>
+				sass::InputSyntax::SASS,
+			"scss" =>
+				sass::InputSyntax::SCSS,
+			_ =>
+				panic! ("[90668feb]"),
+		};
+		
+		pub struct Importer { parent : PathBuf, resolved : rc::Rc<cell::RefCell<Vec<Box<Path>>>> }
+		impl sass::SassImporter for Importer {
+			fn callback (&mut self, _path_0 : &ffi::CStr, _compiler : sass::SassCompiler) -> Result<Option<Vec<sass::SassImportEntry>>, sass::SassImporterError> {
+				
+				let _path_0 = Path::new (_path_0.to_str () .expect ("[fd5fc0a2]"));
+				let _path = self.parent.join (_path_0);
+				
+				for _extension in &["sass", "scss", "css"] {
+					let _path = _path.with_extension (_extension);
+					if ! _path.exists () {
+						continue;
+					}
+					let _path = normalize_path (&_path);
+					// eprintln! ("[dd] [d84fd5f5] {} -> {}", _path_0.display (), _path.display ());
+					
+					// NOTE:  The code bellow will keep a reference to `_path` that should live until after the compilation completes.
+					let mut _resolved = self.resolved.borrow_mut ();
+					_resolved.push (_path.into_boxed_path ());
+					let _path = _resolved.last () .expect ("[5d9cba96]") .as_ref ();
+					let _entry = sass::SassImport::AbsolutePath (_path);
+					
+					return Ok (Some (vec! (_entry.into_sass_import_entry ())));
+				}
+				
+				panic! ("[e9c920d0] {}", _path.display ());
+			}
+		}
+		impl fmt::Debug for Importer {
+			fn fmt (&self, _formatter: &mut fmt::Formatter<'_>) -> fmt::Result {
+				_formatter.write_str ("SassImporter()")
+			}
+		}
+		
+		let _resolved = rc::Rc::new (cell::RefCell::new (Vec::new ()));
+		let _importer = Box::new (Importer { parent : _parent.into (), resolved : _resolved.clone () });
+		
+		let _options = sass::SassOptions {
+				output_style : sass::OutputStyle::Expanded,
+				source_comments : true,
+				source_map_embed : false,
+				source_map_contents : false,
+				source_map_file_urls : false,
+				omit_source_map_url : true,
+				indent : ffi::CString::new ("\t") .expect ("[77771198]"),
+				linefeed : ffi::CString::new ("\n") .expect ("[ef2eea09]"),
+				precision : 4,
+				input_syntax : _input_syntax,
+				include_paths : &[],
+				function_list : rc::Rc::new (sass::SassFunctionList::new (Vec::new ())),
+				importer_list : rc::Rc::new (sass::SassImporterList::new (vec! (_importer))),
+				header_list : rc::Rc::new (sass::SassImporterList::new (Vec::new ())),
+			};
+		
+		let _data = _options.compile_file (_source) .expect ("[bbaffa6f]");
+		
+		for _dependency in _resolved.borrow () .iter () {
+			self.dependencies_include (_dependency.as_ref ());
+		}
+		
+		return Ok (_data);
+	}
 }
 
 
@@ -769,6 +900,7 @@ fn detect_content_type_from_extension (_source : &Path) -> &'static str {
 
 
 
+#[ allow (dead_code) ]
 fn fingerprint_data (_data : impl AsRef<[u8]>) -> String {
 	use blake2::Digest as _;
 	let mut _hasher = blake2::Blake2b::new ();
